@@ -95,7 +95,20 @@ class Edge(Entity):
         if isinstance(tags, dict):
             tags = Tags(**tags)
         if __debug__:
-            type_hints = typing.get_type_hints(Edge.__init__)
+            def stub(
+                *,
+                uuid: builtins.str,
+                attributes: typing.Optional[typing.Union[Attributes, typing.Dict[str, typing.Any]]] = None,
+                flags: typing.Optional[typing.Sequence[_FlagEnum_af90e158]] = None,
+                metadata: typing.Optional[typing.Sequence[typing.Union[constructs.MetadataEntry, typing.Dict[str, typing.Any]]]] = None,
+                tags: typing.Optional[typing.Union[Tags, typing.Dict[str, typing.Any]]] = None,
+                direction: _EdgeDirectionEnum_26ef4ba3,
+                edge_type: _EdgeTypeEnum_1b13d7ee,
+                source: builtins.str,
+                target: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument uuid", value=uuid, expected_type=type_hints["uuid"])
             check_type(argname="argument attributes", value=attributes, expected_type=type_hints["attributes"])
             check_type(argname="argument flags", value=flags, expected_type=type_hints["flags"])
@@ -259,7 +272,16 @@ class Entity:
         if isinstance(tags, dict):
             tags = Tags(**tags)
         if __debug__:
-            type_hints = typing.get_type_hints(Entity.__init__)
+            def stub(
+                *,
+                uuid: builtins.str,
+                attributes: typing.Optional[typing.Union[Attributes, typing.Dict[str, typing.Any]]] = None,
+                flags: typing.Optional[typing.Sequence[_FlagEnum_af90e158]] = None,
+                metadata: typing.Optional[typing.Sequence[typing.Union[constructs.MetadataEntry, typing.Dict[str, typing.Any]]]] = None,
+                tags: typing.Optional[typing.Union[Tags, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument uuid", value=uuid, expected_type=type_hints["uuid"])
             check_type(argname="argument attributes", value=attributes, expected_type=type_hints["attributes"])
             check_type(argname="argument flags", value=flags, expected_type=type_hints["flags"])
@@ -363,7 +385,14 @@ class GraphStore:
         if isinstance(tree, dict):
             tree = Node(**tree)
         if __debug__:
-            type_hints = typing.get_type_hints(GraphStore.__init__)
+            def stub(
+                *,
+                edges: typing.Sequence[typing.Union[Edge, typing.Dict[str, typing.Any]]],
+                tree: typing.Union[Node, typing.Dict[str, typing.Any]],
+                version: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument edges", value=edges, expected_type=type_hints["edges"])
             check_type(argname="argument tree", value=tree, expected_type=type_hints["tree"])
             check_type(argname="argument version", value=version, expected_type=type_hints["version"])
@@ -594,7 +623,26 @@ class Node(Entity):
         if isinstance(construct_info, dict):
             construct_info = _ConstructInfo_e912d4bb(**construct_info)
         if __debug__:
-            type_hints = typing.get_type_hints(Node.__init__)
+            def stub(
+                *,
+                uuid: builtins.str,
+                attributes: typing.Optional[typing.Union[Attributes, typing.Dict[str, typing.Any]]] = None,
+                flags: typing.Optional[typing.Sequence[_FlagEnum_af90e158]] = None,
+                metadata: typing.Optional[typing.Sequence[typing.Union[constructs.MetadataEntry, typing.Dict[str, typing.Any]]]] = None,
+                tags: typing.Optional[typing.Union[Tags, typing.Dict[str, typing.Any]]] = None,
+                id: builtins.str,
+                node_type: _NodeTypeEnum_d56eed04,
+                path: builtins.str,
+                cfn_type: typing.Optional[builtins.str] = None,
+                children: typing.Optional[typing.Mapping[builtins.str, typing.Union[Node, typing.Dict[str, typing.Any]]]] = None,
+                construct_info: typing.Optional[typing.Union[_ConstructInfo_e912d4bb, typing.Dict[str, typing.Any]]] = None,
+                edges: typing.Optional[typing.Sequence[builtins.str]] = None,
+                logical_id: typing.Optional[builtins.str] = None,
+                parent: typing.Optional[builtins.str] = None,
+                stack: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument uuid", value=uuid, expected_type=type_hints["uuid"])
             check_type(argname="argument attributes", value=attributes, expected_type=type_hints["attributes"])
             check_type(argname="argument flags", value=flags, expected_type=type_hints["flags"])
